@@ -16,7 +16,7 @@ class DatoTrainer(object):
     def __init__(self, dato_mapper: DatoMapper):
         """Create DatoTrainer object for training a generative model for the mapped input data.
         Args:
-            dato_mapper: the Datomapper object for the input data."""
+            dato_mapper: the DatoMapper object for the input data."""
         dato_mapper.next_step_validation()
         self.dato_mapper = dato_mapper
 
@@ -52,6 +52,14 @@ class DatoTrainer(object):
             raise Exception("Trainer Failed")
         self.model_id = train_helper.get_train_iteration(self.dato_mapper, self.train_id)[general.MODELS][0][general.ID]
 
+    def get_generated_data(self) -> None:
+        self.next_step_validation()
+        print(common_helper.get_generated_zip(datomizer=self.dato_mapper.datomizer,
+                                              business_unit_id=self.dato_mapper.business_unit_id,
+                                              project_id=self.dato_mapper.project_id,
+                                              flow_id=self.dato_mapper.flow_id,
+                                              train_id=self.train_id))
+
     def get_generated_data_csv(self, table_name: str = None) -> io.StringIO:
         """Get the generated data in a csv format.
                 Args:
