@@ -1,5 +1,6 @@
+ENV_SUBDOMAIN = "app"
 URL = "https://%s"
-DEFAULT_DOMAIN = "app.datomize.com"
+DEFAULT_DOMAIN = ENV_SUBDOMAIN + ".datomize.com"
 
 MANAGEMENT = "/api"
 ONBOARDING = "/onboarding"
